@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2014 Open-Xchange, Inc.
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,6 +49,7 @@
 
 package com.openexchange.admin.reseller.storage.mysqlStorage;
 
+import static com.openexchange.tools.file.external.QuotaFileStorages.hasUserColumn;
 import static com.openexchange.tools.sql.DBUtils.getIN;
 import java.io.UnsupportedEncodingException;
 import java.security.NoSuchAlgorithmException;
@@ -886,9 +887,13 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
             long qused = 0;
             while (rs.next()) {
                 cid = rs.getInt("cid");
+
+                boolean hasUserColumn = hasUserColumn(con, cid);
+
                 oxcon = cache.getConnectionForContext(cid);
-                prep2 = oxcon.prepareStatement("SELECT filestore_usage.used FROM filestore_usage WHERE filestore_usage.cid = ?");
+                prep2 = oxcon.prepareStatement(hasUserColumn ? "SELECT filestore_usage.used FROM filestore_usage WHERE filestore_usage.cid = ? AND filestore_usage.user = 0" : "SELECT filestore_usage.used FROM filestore_usage WHERE filestore_usage.cid = ?");
                 prep2.setInt(1, cid);
+
                 rs2 = prep2.executeQuery();
                 if (rs2.next()) {
                     qused += rs2.getLong(1);
@@ -908,6 +913,9 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
         } catch (final PoolException e) {
             log.error("", e);
             throw e;
+        } catch (final OXException e) {
+            log.error("", e);
+            throw new StorageException(e);
         } finally {
             cache.closeContextSqlStuff(oxcon, cid, true);
             cache.closeConfigDBSqlStuff(null, prep, rs);
